Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/monodevelop.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMichael Hutchinson <m.j.hutchinson@gmail.com>2011-08-23 14:45:16 +0400
committerMichael Hutchinson <m.j.hutchinson@gmail.com>2011-08-23 18:27:50 +0400
commit86ffb439b30710dab814490402f59fcf9a73f247 (patch)
tree46740626a8ad5495375d4360f067e1a195673c9d /main/src/addins/MonoDevelop.Autotools
parentb828272058dc03b17da05e311484a4fdfe0f8a2b (diff)
[Project] Rename 'Gac' refs to 'Package' refs
This is a couple of years overdue because the "gac" name is wrong, misleading and confusing.
Diffstat (limited to 'main/src/addins/MonoDevelop.Autotools')
-rw-r--r--main/src/addins/MonoDevelop.Autotools/MakefileData.cs108
-rw-r--r--main/src/addins/MonoDevelop.Autotools/MakefileOptionPanelWidget.cs36
-rw-r--r--main/src/addins/MonoDevelop.Autotools/SimpleProjectMakefileHandler.cs2
-rw-r--r--main/src/addins/MonoDevelop.Autotools/gtk-gui/MonoDevelop.Autotools.MakefileOptionPanelWidget.cs44
-rw-r--r--main/src/addins/MonoDevelop.Autotools/gtk-gui/gui.stetic9
5 files changed, 100 insertions, 99 deletions
diff --git a/main/src/addins/MonoDevelop.Autotools/MakefileOptionPanelWidget.cs b/main/src/addins/MonoDevelop.Autotools/MakefileOptionPanelWidget.cs
index 13543386d6..749d767ab2 100644
--- a/main/src/addins/MonoDevelop.Autotools/MakefileOptionPanelWidget.cs
+++ b/main/src/addins/MonoDevelop.Autotools/MakefileOptionPanelWidget.cs
@@ -82,7 +82,7 @@ namespace MonoDevelop.Autotools
//References
this.cbKeepRefSync.Active = data.SyncReferences;
- this.entryGacRefPattern.Text = data.GacRefVar.Prefix;
+ this.entryPackageRefPattern.Text = data.PackageRefVar.Prefix;
this.entryAsmRefPattern.Text = data.AsmRefVar.Prefix;
this.entryProjectRefPattern.Text = data.ProjectRefVar.Prefix;
@@ -139,7 +139,7 @@ namespace MonoDevelop.Autotools
this.Build();
combos = new ComboBox [7] {
comboFilesVar, comboDeployFilesVar, comboResourcesVar, comboOthersVar,
- comboGacRefVar, comboAsmRefVar, comboProjectRefVar};
+ comboPackageRefVar, comboAsmRefVar, comboProjectRefVar};
//comboAssemblyName, comboOutputDir};
}
@@ -174,9 +174,9 @@ namespace MonoDevelop.Autotools
// References
data.SyncReferences = this.cbKeepRefSync.Active;
- data.GacRefVar.Sync = this.cbKeepRefSync.Active;
- data.GacRefVar.Name = GetActiveVar (comboGacRefVar);
- data.GacRefVar.Prefix = this.entryGacRefPattern.Text.Trim ();
+ data.PackageRefVar.Sync = this.cbKeepRefSync.Active;
+ data.PackageRefVar.Name = GetActiveVar (comboPackageRefVar);
+ data.PackageRefVar.Prefix = this.entryPackageRefPattern.Text.Trim ();
data.AsmRefVar.Sync = this.cbKeepRefSync.Active;
data.AsmRefVar.Name = GetActiveVar (comboAsmRefVar);
@@ -229,7 +229,7 @@ namespace MonoDevelop.Autotools
}
if (tmpData.SyncReferences &&
- (String.IsNullOrEmpty (tmpData.GacRefVar.Name) ||
+ (String.IsNullOrEmpty (tmpData.PackageRefVar.Name) ||
String.IsNullOrEmpty (tmpData.AsmRefVar.Name) ||
String.IsNullOrEmpty (tmpData.ProjectRefVar.Name))) {
@@ -340,7 +340,7 @@ namespace MonoDevelop.Autotools
SetActiveVar (comboResourcesVar, data.ResourcesVar.Name);
SetActiveVar (comboOthersVar, data.OthersVar.Name);
- SetActiveVar (comboGacRefVar, data.GacRefVar.Name);
+ SetActiveVar (comboPackageRefVar, data.PackageRefVar.Name);
SetActiveVar (comboAsmRefVar, data.AsmRefVar.Name);
SetActiveVar (comboProjectRefVar, data.ProjectRefVar.Name);
@@ -449,7 +449,7 @@ namespace MonoDevelop.Autotools
string files_var = GetActiveVar (comboFilesVar);
string res_var = GetActiveVar (comboResourcesVar);
- string ref_var = GetActiveVar (comboGacRefVar);
+ string ref_var = GetActiveVar (comboPackageRefVar);
string prefix;
foreach (string var in vars) {
@@ -538,7 +538,7 @@ namespace MonoDevelop.Autotools
cbKeepRefSync.Active = false;
- entryGacRefPattern.Text = String.Empty;
+ entryPackageRefPattern.Text = String.Empty;
entryAsmRefPattern.Text = String.Empty;
entryProjectRefPattern.Text = String.Empty;
@@ -580,11 +580,11 @@ namespace MonoDevelop.Autotools
cbKeepRefSync.Active = true;
HandleKeepRefSyncClicked (cbKeepRefSync);
- SetActiveVar (comboGacRefVar, ref_var);
+ SetActiveVar (comboPackageRefVar, ref_var);
SetActiveVar (comboAsmRefVar, ref_var);
SetActiveVar (comboProjectRefVar, ref_var);
- entryGacRefPattern.Text = prefix;
+ entryPackageRefPattern.Text = prefix;
entryAsmRefPattern.Text = prefix;
entryProjectRefPattern.Text = prefix;
}
@@ -667,9 +667,9 @@ namespace MonoDevelop.Autotools
this.lblCol5.Sensitive = state;
this.lblCol6.Sensitive = state;
- this.lblGacRef.Sensitive = state;
- this.comboGacRefVar.Sensitive = state;
- this.entryGacRefPattern.Sensitive = state;
+ this.lblPackageRef.Sensitive = state;
+ this.comboPackageRefVar.Sensitive = state;
+ this.entryPackageRefPattern.Sensitive = state;
this.lblAsmRef.Sensitive = state;
this.comboAsmRefVar.Sensitive = state;
@@ -891,15 +891,15 @@ namespace MonoDevelop.Autotools
}
}
- protected virtual void OnComboGacRefVarChanged (object sender, System.EventArgs e)
+ protected virtual void OnComboPackageRefVarChanged (object sender, System.EventArgs e)
{
- HandleComboGacRefVarChanged ((ComboBox) sender);
+ HandleComboPackageRefVarChanged ((ComboBox) sender);
}
- void HandleComboGacRefVarChanged (ComboBox cb)
+ void HandleComboPackageRefVarChanged (ComboBox cb)
{
string active = GetActiveVar (cb);
- entryGacRefPattern.Text = GuessRefPrefix (data.Makefile.GetListVariable (active));
+ entryPackageRefPattern.Text = GuessRefPrefix (data.Makefile.GetListVariable (active));
}
protected virtual void OnComboAsmRefVarChanged (object sender, System.EventArgs e)
diff --git a/main/src/addins/MonoDevelop.Autotools/SimpleProjectMakefileHandler.cs b/main/src/addins/MonoDevelop.Autotools/SimpleProjectMakefileHandler.cs
index 89b7a41806..6f4d39496f 100644
--- a/main/src/addins/MonoDevelop.Autotools/SimpleProjectMakefileHandler.cs
+++ b/main/src/addins/MonoDevelop.Autotools/SimpleProjectMakefileHandler.cs
@@ -497,7 +497,7 @@ endif", s.SwitchName.Replace ('-', '_').ToUpperInvariant (), s.Define));
// grab pkg-config references
foreach (ProjectReference reference in project.References)
{
- if (reference.ReferenceType == ReferenceType.Gac)
+ if (reference.ReferenceType == ReferenceType.Package)
{
// Get pkg-config keys
SystemPackage pkg = reference.Package;
diff --git a/main/src/addins/MonoDevelop.Autotools/gtk-gui/MonoDevelop.Autotools.MakefileOptionPanelWidget.cs b/main/src/addins/MonoDevelop.Autotools/gtk-gui/MonoDevelop.Autotools.MakefileOptionPanelWidget.cs
index 48f6c01efa..ff40f01a6d 100644
--- a/main/src/addins/MonoDevelop.Autotools/gtk-gui/MonoDevelop.Autotools.MakefileOptionPanelWidget.cs
+++ b/main/src/addins/MonoDevelop.Autotools/gtk-gui/MonoDevelop.Autotools.MakefileOptionPanelWidget.cs
@@ -58,10 +58,10 @@ namespace MonoDevelop.Autotools
private global::Gtk.Table table4;
private global::Gtk.CheckButton cbAutotoolsProject;
private global::Gtk.ComboBox comboAsmRefVar;
- private global::Gtk.ComboBox comboGacRefVar;
+ private global::Gtk.ComboBox comboPackageRefVar;
private global::Gtk.ComboBox comboProjectRefVar;
private global::Gtk.Entry entryAsmRefPattern;
- private global::Gtk.Entry entryGacRefPattern;
+ private global::Gtk.Entry entryPackageRefPattern;
private global::Gtk.Entry entryProjectRefPattern;
private global::MonoDevelop.Components.FolderEntry fileEntryConfigureInPath;
private global::Gtk.HSeparator hseparator1;
@@ -70,7 +70,7 @@ namespace MonoDevelop.Autotools
private global::Gtk.Label lblCol5;
private global::Gtk.Label lblCol6;
private global::Gtk.Label lblConfigureInPath;
- private global::Gtk.Label lblGacRef;
+ private global::Gtk.Label lblPackageRef;
private global::Gtk.Label lblProjectRef;
private global::Gtk.Label label3;
private global::Gtk.VBox vbox3;
@@ -666,11 +666,11 @@ namespace MonoDevelop.Autotools
w49.RightAttach = ((uint)(2));
w49.YOptions = ((global::Gtk.AttachOptions)(4));
// Container child table4.Gtk.Table+TableChild
- this.comboGacRefVar = global::Gtk.ComboBox.NewText ();
- this.comboGacRefVar.WidthRequest = 200;
- this.comboGacRefVar.Name = "comboGacRefVar";
- this.table4.Add (this.comboGacRefVar);
- global::Gtk.Table.TableChild w50 = ((global::Gtk.Table.TableChild)(this.table4 [this.comboGacRefVar]));
+ this.comboPackageRefVar = global::Gtk.ComboBox.NewText ();
+ this.comboPackageRefVar.WidthRequest = 200;
+ this.comboPackageRefVar.Name = "comboPackageRefVar";
+ this.table4.Add (this.comboPackageRefVar);
+ global::Gtk.Table.TableChild w50 = ((global::Gtk.Table.TableChild)(this.table4 [this.comboPackageRefVar]));
w50.TopAttach = ((uint)(2));
w50.BottomAttach = ((uint)(3));
w50.LeftAttach = ((uint)(1));
@@ -702,13 +702,13 @@ namespace MonoDevelop.Autotools
w52.XOptions = ((global::Gtk.AttachOptions)(4));
w52.YOptions = ((global::Gtk.AttachOptions)(4));
// Container child table4.Gtk.Table+TableChild
- this.entryGacRefPattern = new global::Gtk.Entry ();
- this.entryGacRefPattern.CanFocus = true;
- this.entryGacRefPattern.Name = "entryGacRefPattern";
- this.entryGacRefPattern.IsEditable = true;
- this.entryGacRefPattern.InvisibleChar = '●';
- this.table4.Add (this.entryGacRefPattern);
- global::Gtk.Table.TableChild w53 = ((global::Gtk.Table.TableChild)(this.table4 [this.entryGacRefPattern]));
+ this.entryPackageRefPattern = new global::Gtk.Entry ();
+ this.entryPackageRefPattern.CanFocus = true;
+ this.entryPackageRefPattern.Name = "entryPackageRefPattern";
+ this.entryPackageRefPattern.IsEditable = true;
+ this.entryPackageRefPattern.InvisibleChar = '●';
+ this.table4.Add (this.entryPackageRefPattern);
+ global::Gtk.Table.TableChild w53 = ((global::Gtk.Table.TableChild)(this.table4 [this.entryPackageRefPattern]));
w53.TopAttach = ((uint)(2));
w53.BottomAttach = ((uint)(3));
w53.LeftAttach = ((uint)(2));
@@ -812,12 +812,12 @@ namespace MonoDevelop.Autotools
w61.XOptions = ((global::Gtk.AttachOptions)(4));
w61.YOptions = ((global::Gtk.AttachOptions)(4));
// Container child table4.Gtk.Table+TableChild
- this.lblGacRef = new global::Gtk.Label ();
- this.lblGacRef.Name = "lblGacRef";
- this.lblGacRef.Xalign = 0F;
- this.lblGacRef.LabelProp = global::Mono.Unix.Catalog.GetString ("Package References");
- this.table4.Add (this.lblGacRef);
- global::Gtk.Table.TableChild w62 = ((global::Gtk.Table.TableChild)(this.table4 [this.lblGacRef]));
+ this.lblPackageRef = new global::Gtk.Label ();
+ this.lblPackageRef.Name = "lblPackageRef";
+ this.lblPackageRef.Xalign = 0F;
+ this.lblPackageRef.LabelProp = global::Mono.Unix.Catalog.GetString ("Package References");
+ this.table4.Add (this.lblPackageRef);
+ global::Gtk.Table.TableChild w62 = ((global::Gtk.Table.TableChild)(this.table4 [this.lblPackageRef]));
w62.TopAttach = ((uint)(2));
w62.BottomAttach = ((uint)(3));
w62.XOptions = ((global::Gtk.AttachOptions)(4));
@@ -983,7 +983,7 @@ namespace MonoDevelop.Autotools
this.cbKeepDeployFilesSync.Clicked += new global::System.EventHandler (this.OnCbKeepDeployFilesSyncClicked);
this.cbKeepRefSync.Clicked += new global::System.EventHandler (this.OnCbKeepRefSyncClicked);
this.comboProjectRefVar.Changed += new global::System.EventHandler (this.OnComboProjectRefVarChanged);
- this.comboGacRefVar.Changed += new global::System.EventHandler (this.OnComboGacRefVarChanged);
+ this.comboPackageRefVar.Changed += new global::System.EventHandler (this.OnComboPackageRefVarChanged);
this.comboAsmRefVar.Changed += new global::System.EventHandler (this.OnComboAsmRefVarChanged);
this.cbAutotoolsProject.Clicked += new global::System.EventHandler (this.OnCbAutotoolsProjectClicked);
this.comboMessageType.Changed += new global::System.EventHandler (this.OnComboMessageTypeChanged);
diff --git a/main/src/addins/MonoDevelop.Autotools/gtk-gui/gui.stetic b/main/src/addins/MonoDevelop.Autotools/gtk-gui/gui.stetic
index 1b47509a67..58f863550b 100644
--- a/main/src/addins/MonoDevelop.Autotools/gtk-gui/gui.stetic
+++ b/main/src/addins/MonoDevelop.Autotools/gtk-gui/gui.stetic
@@ -7,6 +7,7 @@
<import>
<widget-library name="../../../../build/bin/MonoDevelop.Ide.dll" />
<widget-library name="../../../../build/AddIns/MonoDevelop.DesignerSupport/MonoDevelop.DesignerSupport.dll" />
+ <widget-library name="../../../../build/AddIns/MonoDevelop.Deployment/MonoDevelop.Deployment.dll" />
<widget-library name="../../../../build/AddIns/MonoDevelop.Autotools/MonoDevelop.Autotools.dll" internal="true" />
</import>
<widget class="Gtk.Bin" id="MonoDevelop.Autotools.MakefileOptionPanelWidget" design-size="589 368">
@@ -1005,12 +1006,12 @@
</packing>
</child>
<child>
- <widget class="Gtk.ComboBox" id="comboGacRefVar">
+ <widget class="Gtk.ComboBox" id="comboPackageRefVar">
<property name="MemberName" />
<property name="WidthRequest">200</property>
<property name="IsTextCombo">True</property>
<property name="Items" />
- <signal name="Changed" handler="OnComboGacRefVarChanged" />
+ <signal name="Changed" handler="OnComboPackageRefVarChanged" />
</widget>
<packing>
<property name="TopAttach">2</property>
@@ -1074,7 +1075,7 @@
</packing>
</child>
<child>
- <widget class="Gtk.Entry" id="entryGacRefPattern">
+ <widget class="Gtk.Entry" id="entryPackageRefPattern">
<property name="MemberName" />
<property name="CanFocus">True</property>
<property name="IsEditable">True</property>
@@ -1265,7 +1266,7 @@
</packing>
</child>
<child>
- <widget class="Gtk.Label" id="lblGacRef">
+ <widget class="Gtk.Label" id="lblPackageRef">
<property name="MemberName" />
<property name="Xalign">0</property>
<property name="LabelProp" translatable="yes">Package References</property>
diff --git a/main/src/addins/MonoDevelop.Autotools/MakefileData.cs b/main/src/addins/MonoDevelop.Autotools/MakefileData.cs
index 01b9aeef39..1f96b15947 100644
--- a/main/src/addins/MonoDevelop.Autotools/MakefileData.cs
+++ b/main/src/addins/MonoDevelop.Autotools/MakefileData.cs
@@ -253,7 +253,7 @@ namespace MonoDevelop.Autotools
public bool SyncReferences {
get { return syncReferences; }
set {
- GacRefVar.Sync = value;
+ PackageRefVar.Sync = value;
AsmRefVar.Sync = value;
ProjectRefVar.Sync =value;
syncReferences = value;
@@ -278,15 +278,15 @@ namespace MonoDevelop.Autotools
get { return ConfiguredPackages != null; }
}
- MakefileVar gacRefVar;
+ MakefileVar packageRefVar;
[ItemProperty]
- public MakefileVar GacRefVar {
+ public MakefileVar PackageRefVar {
get {
- if (gacRefVar == null)
- gacRefVar = new MakefileVar ();
- return gacRefVar;
+ if (packageRefVar == null)
+ packageRefVar = new MakefileVar ();
+ return packageRefVar;
}
- set { gacRefVar = value; }
+ set { packageRefVar = value; }
}
MakefileVar asmRefVar;
@@ -491,7 +491,7 @@ namespace MonoDevelop.Autotools
data.DeployFilesVar = new MakefileVar (this.DeployFilesVar);
data.ResourcesVar = new MakefileVar (this.ResourcesVar);
data.OthersVar = new MakefileVar (this.OthersVar);
- data.GacRefVar = new MakefileVar (this.GacRefVar);
+ data.PackageRefVar = new MakefileVar (this.PackageRefVar);
data.AsmRefVar = new MakefileVar (this.AsmRefVar);
data.ProjectRefVar = new MakefileVar (this.ProjectRefVar);
@@ -626,7 +626,7 @@ namespace MonoDevelop.Autotools
encodeValues [OthersVar.Name] = false;
encodeValues [ResourcesVar.Name] = false;
- encodeValues [GacRefVar.Name] = false;
+ encodeValues [PackageRefVar.Name] = false;
encodeValues [AsmRefVar.Name] = false;
encodeValues [ProjectRefVar.Name] = false;
}
@@ -734,22 +734,22 @@ namespace MonoDevelop.Autotools
//Do these for DotNetProject only
DotNetProject dotnetProject = ownerProject as DotNetProject;
if (dotnetProject != null) {
- GacRefVar.Extra.Clear ();
+ PackageRefVar.Extra.Clear ();
AsmRefVar.Extra.Clear ();
ProjectRefVar.Extra.Clear ();
- existingGacRefs = new Dictionary<string, ProjectReference> ();
+ existingPackageRefs = new Dictionary<string, ProjectReference> ();
requiredPackageVersions = new Dictionary<string,string> ();
- newGacRefs = new Dictionary<string, ProjectReference> ();
+ newPackageRefs = new Dictionary<string, ProjectReference> ();
List<ProjectReference> toRemove = new List<ProjectReference> ();
foreach (ProjectReference pref in dotnetProject.References) {
- if (pref.ReferenceType == ReferenceType.Gac) {
+ if (pref.ReferenceType == ReferenceType.Package) {
string [] files = pref.GetReferencedFileNames (ConfigurationSelector.Default);
if (files == null)
continue;
- if (pref.ReferenceType == ReferenceType.Gac) {
+ if (pref.ReferenceType == ReferenceType.Package) {
// Store the package version required by this reference. We'll use
// the same version when trying to match references coming from the makefile
SystemAssembly asm = assemblyContext.GetAssemblyFromFullName (pref.StoredReference, pref.Package != null ? pref.Package.Name : null, dotnetProject.TargetFramework);
@@ -758,10 +758,10 @@ namespace MonoDevelop.Autotools
}
// this should help normalize paths like /foo//bar/../
string fullpath = Path.GetFullPath (files [0]);
- if (existingGacRefs.ContainsKey (fullpath))
+ if (existingPackageRefs.ContainsKey (fullpath))
toRemove.Add (pref);
else
- existingGacRefs [fullpath] = pref;
+ existingPackageRefs [fullpath] = pref;
}
}
@@ -769,12 +769,12 @@ namespace MonoDevelop.Autotools
foreach (ProjectReference pref in toRemove)
dotnetProject.References.Remove (pref);
- ReadReferences (GacRefVar, ReferenceType.Gac, "Gac References", dotnetProject);
+ ReadReferences (PackageRefVar, ReferenceType.Package, "Package References", dotnetProject);
// !SaveReferences indicates that previous ref reading failed
- if (SaveReferences && String.Compare (AsmRefVar.Name, GacRefVar.Name) != 0)
+ if (SaveReferences && String.Compare (AsmRefVar.Name, PackageRefVar.Name) != 0)
ReadReferences (AsmRefVar, ReferenceType.Assembly, "Asm References", dotnetProject);
- if (SaveReferences && (String.Compare (ProjectRefVar.Name, GacRefVar.Name) != 0) &&
+ if (SaveReferences && (String.Compare (ProjectRefVar.Name, PackageRefVar.Name) != 0) &&
(String.Compare (ProjectRefVar.Name, AsmRefVar.Name) != 0))
ReadReferences (ProjectRefVar, ReferenceType.Project, "Project References", dotnetProject);
@@ -785,12 +785,12 @@ namespace MonoDevelop.Autotools
//only remove unmatched existing refs if everything resolved without errors
if (SaveReferences) {
- foreach (ProjectReference pr in existingGacRefs.Values)
+ foreach (ProjectReference pr in existingPackageRefs.Values)
dotnetProject.References.Remove (pr);
}
- existingGacRefs.Clear ();
- newGacRefs.Clear ();
+ existingPackageRefs.Clear ();
+ newPackageRefs.Clear ();
}
} catch (Exception e) {
string msg = GettextCatalog.GetString (
@@ -926,8 +926,8 @@ namespace MonoDevelop.Autotools
}
}
- Dictionary<string, ProjectReference> existingGacRefs = null;
- Dictionary<string, ProjectReference> newGacRefs = null;
+ Dictionary<string, ProjectReference> existingPackageRefs = null;
+ Dictionary<string, ProjectReference> newPackageRefs = null;
Dictionary<string, string> requiredPackageVersions = null;
void ReadReferences (MakefileVar refVar, ReferenceType refType, string id, DotNetProject project)
@@ -1066,13 +1066,13 @@ namespace MonoDevelop.Autotools
string fullpath = Path.GetFullPath (Path.Combine (BaseDirectory, refname));
- // if refname is part of a package then add as gac
+ // if refname is part of a package then add as package
// but don't do it if the refname exactly matches a file name in the project dir
if (refname.IndexOf (Path.DirectorySeparatorChar) < 0 && !File.Exists (fullpath) &&
- ParseReferenceAsGac (refname, project) != null)
+ ParseReferenceAsPackage (refname, project) != null)
continue;
- if (TryGetExistingGacRef (fullpath) != null)
+ if (TryGetExistingPackageRef (fullpath) != null)
continue;
if (refname.IndexOf (Path.DirectorySeparatorChar) < 0) {
@@ -1084,12 +1084,12 @@ namespace MonoDevelop.Autotools
} catch (BadImageFormatException) {
}
- // Valid assembly, From a package, add as Gac
+ // Valid assembly, From a package, add as Package
SystemPackage pkg = assemblyContext.GetPackageFromPath (fullpath);
if (fullname != null && pkg != null) {
SystemAssembly sa = assemblyContext.GetAssemblyFromFullName (fullname, pkg.Name, project.TargetFramework);
if (sa != null) {
- AddNewGacReference (project, sa);
+ AddNewPackageReference (project, sa);
continue;
}
}
@@ -1118,17 +1118,17 @@ namespace MonoDevelop.Autotools
}
foreach (SystemAssembly sa in pkg.Assemblies) {
- if (TryGetExistingGacRef (sa.Location) != null)
+ if (TryGetExistingPackageRef (sa.Location) != null)
continue;
//Get fullname of the assembly
- AddNewGacReference (project, sa);
+ AddNewPackageReference (project, sa);
}
return true;
}
- ProjectReference ParseReferenceAsGac (string rname, DotNetProject project)
+ ProjectReference ParseReferenceAsPackage (string rname, DotNetProject project)
{
string aname = rname;
if (rname.EndsWith (".dll", StringComparison.InvariantCultureIgnoreCase))
@@ -1143,34 +1143,34 @@ namespace MonoDevelop.Autotools
if (asm == null)
return null;
- ProjectReference pref = TryGetExistingGacRef (asm.Location);
+ ProjectReference pref = TryGetExistingPackageRef (asm.Location);
if (pref != null)
return pref;
- return AddNewGacReference (project, asm);
+ return AddNewPackageReference (project, asm);
}
- ProjectReference TryGetExistingGacRef (string fullpath)
+ ProjectReference TryGetExistingPackageRef (string fullpath)
{
- if (existingGacRefs.ContainsKey (fullpath)) {
- ProjectReference ret = existingGacRefs [fullpath];
- existingGacRefs.Remove (fullpath);
- newGacRefs [fullpath] = ret;
+ if (existingPackageRefs.ContainsKey (fullpath)) {
+ ProjectReference ret = existingPackageRefs [fullpath];
+ existingPackageRefs.Remove (fullpath);
+ newPackageRefs [fullpath] = ret;
return ret;
}
- if (newGacRefs.ContainsKey (fullpath))
- return newGacRefs [fullpath];
+ if (newPackageRefs.ContainsKey (fullpath))
+ return newPackageRefs [fullpath];
return null;
}
- ProjectReference AddNewGacReference (DotNetProject project, SystemAssembly sa)
+ ProjectReference AddNewPackageReference (DotNetProject project, SystemAssembly sa)
{
ProjectReference pref = new ProjectReference (sa);
project.References.Add (pref);
- newGacRefs [sa.Location] = pref;
+ newPackageRefs [sa.Location] = pref;
return pref;
}
@@ -1341,11 +1341,11 @@ namespace MonoDevelop.Autotools
WriteFiles (ResourcesVar, BuildAction.EmbeddedResource, makeRelative, "Resources");
if (SyncReferences && SaveReferences) {
- Makefile.ClearVariableValue (GacRefVar.Name);
+ Makefile.ClearVariableValue (PackageRefVar.Name);
Makefile.ClearVariableValue (AsmRefVar.Name);
Makefile.ClearVariableValue (ProjectRefVar.Name);
- WriteReferences (GacRefVar, ReferenceType.Gac, makeRelative, "Gac");
+ WriteReferences (PackageRefVar, ReferenceType.Package, makeRelative, "Package");
WriteReferences (AsmRefVar, ReferenceType.Assembly, makeRelative, "Assembly");
WriteReferences (ProjectRefVar, ReferenceType.Project, makeRelative, "Project");
@@ -1353,17 +1353,17 @@ namespace MonoDevelop.Autotools
// but sort only once per distinct var
// (Required as we are comparing the full makefile as a string,
// to detect changes!)
- List<string> list = Makefile.GetListVariable (GacRefVar.Name);
+ List<string> list = Makefile.GetListVariable (PackageRefVar.Name);
if (list != null)
list.Sort (System.StringComparer.InvariantCulture);
- if (String.Compare (AsmRefVar.Name, GacRefVar.Name) != 0) {
+ if (String.Compare (AsmRefVar.Name, PackageRefVar.Name) != 0) {
list = Makefile.GetListVariable (AsmRefVar.Name);
if (list != null)
list.Sort (System.StringComparer.InvariantCulture);
}
- if ((String.Compare (ProjectRefVar.Name, GacRefVar.Name) != 0) &&
+ if ((String.Compare (ProjectRefVar.Name, PackageRefVar.Name) != 0) &&
(String.Compare (ProjectRefVar.Name, AsmRefVar.Name) != 0)) {
list = Makefile.GetListVariable (ProjectRefVar.Name);
if (list != null)
@@ -1439,7 +1439,7 @@ namespace MonoDevelop.Autotools
bool WriteReferences (MakefileVar refVar, ReferenceType refType, bool makeRelative, string id)
{
//Reference vars can be shared too, so use existing list
//Eg. REF for both Gac and Asm ref
List<string> references = Makefile.GetListVariable (refVar.Name);
if (references == null) {
//Var not found, skip
@@ -1462,9 +1462,9 @@ namespace MonoDevelop.Autotools
string refstr = String.Empty;
switch (refType) {
- case ReferenceType.Gac:
- //Assemblies coming from packages are always added as Gac
- refstr = GacRefToString (pr, hasAcSubstPackages, refVar);
+ case ReferenceType.Package:
+ //Assemblies coming from packages are always added as Package
+ refstr = PackageRefToString (pr, hasAcSubstPackages, refVar);
if (refstr == null)
continue;
break;
@@ -1499,9 +1499,9 @@ namespace MonoDevelop.Autotools
return true;
}
- string GacRefToString (ProjectReference pr, Dictionary<string, bool> hasAcSubstPackages, MakefileVar refVar)
+ string PackageRefToString (ProjectReference pr, Dictionary<string, bool> hasAcSubstPackages, MakefileVar refVar)
{
//Gac ref can be a full name OR a path!
//FIXME: Use GetReferencedFileName and GetPackageFromPath ?
string fullname = pr.Reference;
SystemPackage pkg = pr.Package;
@@ -1439,7 +1439,7 @@ namespace MonoDevelop.Autotools
{
//Reference vars can be shared too, so use existing list
- //Eg. REF for both Gac and Asm ref
+ //Eg. REF for both Package and Asm ref
List<string> references = Makefile.GetListVariable (refVar.Name);
if (references == null) {
@@ -1499,9 +1499,9 @@ namespace MonoDevelop.Autotools
{
- //Gac ref can be a full name OR a path!
+ //Package ref can be a full name OR a path!
//FIXME: Use GetReferencedFileName and GetPackageFromPath ?
string fullname = pr.Reference;